# JSON Pull
The first name of this package was supposed to be jsontools. But there was another package with that name. So we chose the name jsonpull.
This package is supposed to provide interesting tools for working with JSON.
Currently, only has JPrint. JPrint format the output of JSON objects for printing.
We will add better features in the future.

## Installing
Installing using `pip` :
```bash
    pip install jsonpull
```
## Importing  and using

```python
    import jsonpull
    
    obj = "Your JSON Object"
    jprint(obj)
```

